@@ -3,9 +3,14 @@ use warnings;
 package Dist::Zilla::PluginBundle::Author::OpusVL;
 
 use Moose;
-with 'Dist::Zilla::Role::PluginBundle::Easy';
+use 5.014;
+with (
+    'Dist::Zilla::Role::PluginBundle::Easy',
+    'Dist::Zilla::Role::PluginBundle::PluginRemover',
+    'Dist::Zilla::Role::PluginBundle::Config::Slicer',
+);
 
-our $VERSION = '0.009';
+our $VERSION = '0.010';
  
 use Dist::Zilla::PluginBundle::Basic;
 use Dist::Zilla::PluginBundle::Filter;
@@ -16,24 +21,23 @@ sub configure {
 
     die "CPAN::Mini::Inject::REST hostname must be set in mcpani_host"
         if not $self->payload->{mcpani_host};
+
+    my $remove = $self->payload->{ $self->plugin_remover_attribute } || [];
  
     $self->add_plugins(qw(
         Git::GatherDir
         Prereqs::FromCPANfile
     ));
-    $self->add_bundle('@Filter', {
-        '-bundle' => '@Basic',
-        '-remove' => [ 'GatherDir', 'UploadToCPAN', 'TestRelease' ],
+    $self->add_plugins(
+        # Don't try to weave scripts. They have their own POD.
+        [ PodWeaver => { finder => ':InstallModules' } ],
+    );
+    $self->add_bundle('@Starter', {
+        '-remove' => [ 'GatherDir', 'UploadToCPAN', 'TestRelease', @$remove ],
     });
 
     $self->add_plugins(qw(
         AutoPrereqs
-        ReadmeFromPod
-        MetaConfig
-        MetaJSON
-        PodSyntaxTests
-        Test::Compile
-        Test::ReportPrereqs
         CheckChangesHasContent
         RewriteVersion
         NextRelease
@@ -44,8 +48,6 @@ sub configure {
                 match => '\.(png|jpg|db)$',
                 encoding => 'bytes'
         } ],
-        # Don't try to weave scripts. They have their own POD.
-        [ PodWeaver => { finder => ':InstallModules' } ],
         [ 'Git::Commit' =>
             CommitGeneratedFiles => { 
                 allow_dirty => [ qw/dist.ini Changes cpanfile LICENSE/ ]
